# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class ButtonLink(Component):
    """A ButtonLink component.
ButtonLink allows you to create a clickable link within a multi-page app in
the same way as dcc.Link. The standard dcc.Button attributes `n_clicks` 
and `n_clicks_timestamp` have been added to ButtonLink. These attributes
can be used for notification that the ButtonLink has been clicked

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- href (string; optional): The URL of a linked resource.
- disabled (boolean; optional): Set true to disable the component
- refresh (boolean; default False): Controls whether or not the page will refresh when the link is clicked
- className (string; optional): Often used with CSS to style elements with common properties.
- style (dict; optional): Defines CSS styles which will override styles previously set.
- n_clicks (number; default 0): An integer that represents the number of times
that this element has been clicked on.
- n_clicks_timestamp (number; default -1): An integer that represents the time (in ms since 1970)
at which n_clicks changed. This can be used to tell
which button was changed most recently.
- loading_state (dict; optional): Object that holds the loading state object coming from dash-renderer. loading_state has the following type: dict containing keys 'is_loading', 'prop_name', 'component_name'.
Those keys have the following types:
  - is_loading (boolean; optional): Determines if the component is loading or not
  - prop_name (string; optional): Holds which property is loading
  - component_name (string; optional): Holds the name of the component that is loading"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, href=Component.UNDEFINED, disabled=Component.UNDEFINED, refresh=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, n_clicks=Component.UNDEFINED, n_clicks_timestamp=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'href', 'disabled', 'refresh', 'className', 'style', 'n_clicks', 'n_clicks_timestamp', 'loading_state']
        self._type = 'ButtonLink'
        self._namespace = 'dash_holoniq_components/_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'href', 'disabled', 'refresh', 'className', 'style', 'n_clicks', 'n_clicks_timestamp', 'loading_state']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(ButtonLink, self).__init__(children=children, **args)



from .Alert import Alert
from .ButtonLink import ButtonLink
from .Form import Form
from .InputWithIcon import InputWithIcon
from .LayoutRouter import LayoutRouter
from .PageTitle import PageTitle
from .PasswordWithShow import PasswordWithShow
from .Redirect import Redirect

__all__ = [
    "Alert",
    "ButtonLink",
    "Form",
    "InputWithIcon",
    "LayoutRouter",
    "PageTitle",
    "PasswordWithShow",
    "Redirect"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PageTitle(Component):
    """A PageTitle component.
Sets the page title

Keyword arguments:
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- title (string; optional): The the page title.
- loading_state (dict; optional): Object that holds the loading state object coming from dash-renderer. loading_state has the following type: dict containing keys 'is_loading', 'prop_name', 'component_name'.
Those keys have the following types:
  - is_loading (boolean; optional): Determines if the component is loading or not
  - prop_name (string; optional): Holds which property is loading
  - component_name (string; optional): Holds the name of the component that is loading"""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, title=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'title', 'loading_state']
        self._type = 'PageTitle'
        self._namespace = 'dash_holoniq_components/_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'title', 'loading_state']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PageTitle, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Redirect(Component):
    """A Redirect component.
Allows the window history/location to be set to a new value

Keyword arguments:
- id (string; required): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- href (string; optional): href in window.location - e.g., "/my/full/pathname?myargument=1#myhash"
- refresh (boolean; default True): Refresh the page when the location is updated?"""
    @_explicitize_args
    def __init__(self, id=Component.REQUIRED, href=Component.UNDEFINED, refresh=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'href', 'refresh']
        self._type = 'Redirect'
        self._namespace = 'dash_holoniq_components/_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'href', 'refresh']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['id']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Redirect, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Alert(Component):
    """An Alert component.
The Alert component is hidden if it has no children. When
children are defined the Alert component sets its style to
become visible

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- n_clicks (number; default 0): An integer that represents the number of times
that this element has been clicked on.
- n_clicks_timestamp (number; default -1): An integer that represents the time (in ms since 1970)
at which n_clicks changed. This can be used to tell
which button was changed most recently.
- key (string; optional): A unique identifier for the component, used to improve
performance by React.js while rendering components
See https://reactjs.org/docs/lists-and-keys.html for more info
- role (string; optional): The ARIA role attribute
- data-* (string; optional): A wildcard data attribute
- aria-* (string; optional): A wildcard aria attribute
- accessKey (string; optional): Defines a keyboard shortcut to activate or add focus to the element.
- className (string; optional): Often used with CSS to style elements with common properties.
- contentEditable (string; optional): Indicates whether the element's content is editable.
- contextMenu (string; optional): Defines the ID of a <menu> element which will serve as the element's context menu.
- dir (string; optional): Defines the text direction. Allowed values are ltr (Left-To-Right) or rtl (Right-To-Left)
- draggable (string; optional): Defines whether the element can be dragged.
- hidden (a value equal to: 'hidden', 'HIDDEN' | boolean; optional): Prevents rendering of given element, while keeping child elements, e.g. script elements, active.
- lang (string; optional): Defines the language used in the element.
- spellCheck (string; optional): Indicates whether spell checking is allowed for the element.
- style (dict; optional): Defines CSS styles which will override styles previously set.
- tabIndex (string; optional): Overrides the browser's default tab order and follows the one specified instead.
- title (string; optional): Text to be displayed in a tooltip when hovering over the element.
- loading_state (dict; optional): Object that holds the loading state object coming from dash-renderer. loading_state has the following type: dict containing keys 'is_loading', 'prop_name', 'component_name'.
Those keys have the following types:
  - is_loading (boolean; optional): Determines if the component is loading or not
  - prop_name (string; optional): Holds which property is loading
  - component_name (string; optional): Holds the name of the component that is loading"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, n_clicks=Component.UNDEFINED, n_clicks_timestamp=Component.UNDEFINED, key=Component.UNDEFINED, role=Component.UNDEFINED, accessKey=Component.UNDEFINED, className=Component.UNDEFINED, contentEditable=Component.UNDEFINED, contextMenu=Component.UNDEFINED, dir=Component.UNDEFINED, draggable=Component.UNDEFINED, hidden=Component.UNDEFINED, lang=Component.UNDEFINED, spellCheck=Component.UNDEFINED, style=Component.UNDEFINED, tabIndex=Component.UNDEFINED, title=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'n_clicks', 'n_clicks_timestamp', 'key', 'role', 'data-*', 'aria-*', 'accessKey', 'className', 'contentEditable', 'contextMenu', 'dir', 'draggable', 'hidden', 'lang', 'spellCheck', 'style', 'tabIndex', 'title', 'loading_state']
        self._type = 'Alert'
        self._namespace = 'dash_holoniq_components/_components'
        self._valid_wildcard_attributes =            ['data-', 'aria-']
        self.available_properties = ['children', 'id', 'n_clicks', 'n_clicks_timestamp', 'key', 'role', 'data-*', 'aria-*', 'accessKey', 'className', 'contentEditable', 'contextMenu', 'dir', 'draggable', 'hidden', 'lang', 'spellCheck', 'style', 'tabIndex', 'title', 'loading_state']
        self.available_wildcard_properties =            ['data-', 'aria-']

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Alert, self).__init__(children=children, **args)



import dash
from dash.dependencies import Input, Output
import dash_html_components as html
import dash_holoniq_components as dhc


from app import app

NOUPDATE = dash.no_update

class UserProfile:

    def __init__(self):
        self.signout()

    def set_user(self, user):
        self.user = user

    def signout(self):
        self.user = 'Guest'

    def user_signed_in(self):
        return self.user != 'Guest'


user_profile = UserProfile()


def big_center(text):
    return html.H2(text, className='display-3 text-center')

def layout():

    def signin():
        if user_profile.user == 'Guest':
            return html.Div([
                dhc.ButtonLink('Signin', href='/signin', className="btn btn-primary")
            ], className="col text-center")
        return None

    def signout():

        @app.callback(Output('signout-redirect', 'href'), [Input('signout-btn','n_clicks')])
        def _signout_callback(clicks):
            redirect = NOUPDATE
            if clicks:
                user_profile.signout()
                redirect = '/'

            return redirect


        if user_profile.user != 'Guest':
            return html.Div([
                dhc.Redirect(id='signout-redirect', refresh=True),
                html.Button('Signout', id='signout-btn', className="btn btn-primary")
            ], className="col text-center")
        return None


    return html.Header([
        big_center("Welcome"),
        big_center(user_profile.user),
        html.Br(),
        signin(),
        signout()
    ], className='jumbotron my-4')


from utils import logging, log

import dash
from dash.dependencies import Input, Output

import dash_bootstrap_components as dbc
import dash_holoniq_components as dhc
import dash_html_components as html

from app import app

from .user_profile import user_profile

NOUPDATE = dash.no_update

"""
Shows the Alert, InputWithIcon, PasswordWithShow and Form components
"""

def formFields():
    return [
        dhc.Alert(id='flash', className="alert alert-danger", role="alert"),
        dbc.FormGroup([
            dbc.Label('Name'),
            dhc.InputWithIcon(type='name', id ='name', name='name', 
                              autoComplete='name', placeholder='Enter name', 
                              icon='fa fa-user', tooltip='Hello Big Joe')
        ]),
        dbc.FormGroup([
            dbc.Label('Password'),
            dhc.PasswordWithShow(name='password', id='password', autoComplete='password', 
                                 placeholder='Enter password', 
                                 tooltip='Hide/Show password')
        ]),

        html.Div(
            html.Button('Sign In', type="submit", disabled=False, className="btn btn-primary btn-block"),
            className="form-group m-0")
    ]

def layout():

    @app.callback([Output('signin-redirect', 'href'), Output('flash', 'children')], [Input('form','form_data')])
    def _callback(form_data):
        redirect = NOUPDATE
        flash = None

        if form_data:
            if form_data['name'] == '':
                flash = 'Enter your name'
            elif len(form_data['password']) < 8:
                flash = 'Password must be at least 8 characters'
            else:
                log.info('form data: %s', form_data)
                user_profile.set_user(form_data['name'])
                redirect = '/'
                flash = None

        return redirect, flash

    return  html.Div([
        html.Div([
            dhc.Redirect(id='signin-redirect', refresh=True),
            html.Div(className="col-md-2"),
            html.Div([
                html.Div([
                    html.Div([
                        html.Br(),
                        html.H4('Sign In'),
                        html.Br(),
                        dhc.Form(formFields(), id='form', preventDefault=True),
                        html.Br(),
                    ], className='card-body')
                ], className='card')
            ], className="col-md-8"),
            html.Div(className="col-md-2")
        ], className='row')
    ], className="container-fluid")


#
# python -m examples.form
#
# http://localhost:8050
#

if __name__ == '__main__':
    print('\nvisit: http://localhost:8050\n')

    aps_log = logging.getLogger('werkzeug')
    aps_log.setLevel(logging.ERROR)

    app.layout = layout
    app.run_server(debug=False, threaded=False)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class LayoutRouter(Component):
    """A LayoutRouter component.
The children of LayoutRouter are each wrapped in a Div that is
is hidden/shown based on the current value of the LayoutRouter 'switch' 
attribute.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- key (string; optional): A unique identifier for the component, used to improve
performance by React.js while rendering components
See https://reactjs.org/docs/lists-and-keys.html for more info
- className (string; optional): Often used with CSS to style elements with common properties.
- switch (string; optional): The route to be activated
- routes (list of strings; optional): The route/switch values to be associated with each of the child routes"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, key=Component.UNDEFINED, className=Component.UNDEFINED, switch=Component.UNDEFINED, routes=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'key', 'className', 'switch', 'routes']
        self._type = 'LayoutRouter'
        self._namespace = 'dash_holoniq_components/_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'key', 'className', 'switch', 'routes']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(LayoutRouter, self).__init__(children=children, **args)



from utils import logging, log

import dash
from dash.dependencies import Input, Output

import dash_html_components as html
import dash_bootstrap_components as dbc
import dash_core_components as dcc

from examples.signin_form import layout as signin_form

from examples.user_profile import user_profile
from examples.user_profile import layout as user_profile_layout

import dash_holoniq_components as dhc
from app import app


def page_layout():

    page_layouts = {
        'signin' : signin_form(),
        'default' : user_profile_layout()
    }

    (routes, children) = zip(*page_layouts.items())

    @app.callback([Output('router', 'switch'), Output('title', 'title')], [Input('loc', 'pathname')])
    def _router_callback(pathname):
        route = 'default'
        title = 'My Site: {}'.format(user_profile.user)
        
        log.info('_router_callback pathname=%s', pathname)

        if pathname:
            pathname = pathname[1:]
            if pathname in page_layouts:
                route = pathname

            if route == 'signin' and user_profile.user_signed_in():
                route = 'default'


        return route, title


    return html.Div([
        dhc.PageTitle(title='My Site', id='title'),
        dcc.Location(id='loc'),
        dhc.LayoutRouter(children, routes=routes, id='router')

    ])


def dash_layout_refresh():
    """Clear the Dash layout & callback state prior rebuilding, 
    it's as if this is the first call prior to calling dash.run_server()
    
    Returns:
        [obj] -- Dash layout tree
    """
    try:

        app.callback_map = {}
        app._layout = None

        # Rebuild everything

        layout = page_layout()

    finally:

        # Allow dash to call us again on the next refresh

        app._layout = dash_layout_refresh

    return layout


if __name__ == '__main__':

    # Turn off werkzeug logging as it's very noisy

    aps_log = logging.getLogger('werkzeug')
    aps_log.setLevel(logging.ERROR)

    print('\nvisit http://localhost:8050/\n')

    app.layout = dash_layout_refresh
    app.run_server(debug=False, threaded=False)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class PasswordWithShow(Component):
    """A PasswordWithShow component.
Password input with a show/hide icon that can be clicked
to reveal the password

Keyword arguments:
- tooltip (string; optional): tooltip to associate with glyph
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- style (dict; optional): Defines CSS styles which will override styles previously set.
- className (string; optional): Often used with CSS to style elements with common properties.
- key (string; optional): A unique identifier for the component, used to improve
performance by React.js while rendering components
See https://reactjs.org/docs/lists-and-keys.html for more info
- value (string | number; optional): The value of the Input
- disabled (boolean; optional): Set to True to disable the Input.
- autoComplete (string; optional): This attribute indicates whether the value of the control can be
automatically completed by the browser.
- autoFocus (string; optional): The element should be automatically focused after the page has loaded.
- inputMode (a value equal to: "verbatim", "latin", "latin-name", "latin-prose", "full-width-latin", "kana", "katakana", "numeric", "tel", "email", "url"; optional): The inputmode global attribute is an enumerated attribute that provides 
a hint as to the type of data that might be entered by the user while 
editing the element or its contents. It can have the following values
- list (string; optional): Identifies a list of pre-defined options to suggest to the user.
The value must be the id of a <datalist> element in the same document.
The browser displays only options that are valid values for this
input element.
This attribute is ignored when the type attribute's value is
hidden, checkbox, radio, file, or a button type.
- max (string | number; optional): The maximum (numeric or date-time) value for this item, which must not be
less than its minimum (min attribute) value.
- maxLength (string; optional): If the value of the type attribute is text, email, search, password, tel,
or url, this attribute specifies the maximum number of characters
(in UTF-16 code units) that the user can enter. For other control types,
it is ignored. It can exceed the value of the size attribute. If it is not
specified, the user can enter an unlimited number of characters.
Specifying a negative number results in the default behavior (i.e. the
user can enter an unlimited number of characters). The constraint is
evaluated only when the value of the attribute has been changed.
- min (string | number; optional): The minimum (numeric or date-time) value for this item, which must not be
greater than its maximum (max attribute) value.
- minLength (string; optional): If the value of the type attribute is text, email, search, password, tel,
or url, this attribute specifies the minimum number of characters (in
Unicode code points) that the user can enter. For other control types, it
is ignored.
- step (string | number; optional): Works with the min and max attributes to limit the increments at which a
numeric or date-time value can be set. It can be the string any or a
positive floating point number. If this attribute is not set to any, the
control accepts only values at multiples of the step value greater than
the minimum.
- size (string; optional): The initial size of the control. This value is in pixels unless the value
of the type attribute is text or password, in which case it is an integer
number of characters. This attribute applies only when the type attribute
is set to text, search, tel, url, email, or password, otherwise it is
ignored. In addition, the size must be greater than zero. If you do not
specify a size, a default value of 20 is used.
- bs_size (string; optional): Set the size of the Input. Options: 'sm' (small), 'md' (medium)
or 'lg' (large). Default is 'md'.
- valid (boolean; optional): Apply valid style to the Input for feedback purposes. This will cause
any FormFeedback in the enclosing FormGroup with valid=True to display.
- invalid (boolean; optional): Apply invalid style to the Input for feedback purposes. This will cause
any FormFeedback in the enclosing FormGroup with valid=False to display.
- plaintext (boolean; optional): Set to true for a readonly input styled as plain text with the default
form field styling removed and the correct margins and padding preserved.
- placeholder (string; optional): A hint to the user of what can be entered in the control . The placeholder
text must not contain carriage returns or line-feeds. Note: Do not use the
placeholder attribute instead of a <label> element, their purposes are
different. The <label> attribute describes the role of the form element
(i.e. it indicates what kind of information is expected), and the
placeholder attribute is a hint about the format that the content should
take. There are cases in which the placeholder attribute is never
displayed to the user, so the form must be understandable without it.
- name (string; optional): The name of the control, which is submitted with the form data.
- pattern (string; optional): A regular expression that the control's value is checked against. The
pattern must match the entire value, not just some subset. Use the title
attribute to describe the pattern to help the user. This attribute applies
when the value of the type attribute is text, search, tel, url, email, or
password, otherwise it is ignored. The regular expression language is the
same as JavaScript RegExp algorithm, with the 'u' parameter that makes it
treat the pattern as a sequence of unicode code points. The pattern is not
surrounded by forward slashes.
- n_submit (number; default 0): Number of times the `Enter` key was pressed while the input had focus.
- n_submit_timestamp (number; default -1): Last time that `Enter` was pressed.
- n_blur (number; default 0): Number of times the input lost focus.
- n_blur_timestamp (number; default -1): Last time the input lost focus.
- debounce (boolean; default False): If true, changes to input will be sent back to the Dash server
only when the enter key is pressed or when the component loses
focus.  If it's false, it will sent the value back on every
change.
- loading_state (dict; optional): Object that holds the loading state object coming from dash-renderer. loading_state has the following type: dict containing keys 'is_loading', 'prop_name', 'component_name'.
Those keys have the following types:
  - is_loading (boolean; optional): Determines if the component is loading or not
  - prop_name (string; optional): Holds which property is loading
  - component_name (string; optional): Holds the name of the component that is loading"""
    @_explicitize_args
    def __init__(self, tooltip=Component.UNDEFINED, id=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, value=Component.UNDEFINED, disabled=Component.UNDEFINED, autoComplete=Component.UNDEFINED, autoFocus=Component.UNDEFINED, inputMode=Component.UNDEFINED, list=Component.UNDEFINED, max=Component.UNDEFINED, maxLength=Component.UNDEFINED, min=Component.UNDEFINED, minLength=Component.UNDEFINED, step=Component.UNDEFINED, size=Component.UNDEFINED, bs_size=Component.UNDEFINED, valid=Component.UNDEFINED, invalid=Component.UNDEFINED, plaintext=Component.UNDEFINED, placeholder=Component.UNDEFINED, name=Component.UNDEFINED, pattern=Component.UNDEFINED, n_submit=Component.UNDEFINED, n_submit_timestamp=Component.UNDEFINED, n_blur=Component.UNDEFINED, n_blur_timestamp=Component.UNDEFINED, debounce=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['tooltip', 'id', 'style', 'className', 'key', 'value', 'disabled', 'autoComplete', 'autoFocus', 'inputMode', 'list', 'max', 'maxLength', 'min', 'minLength', 'step', 'size', 'bs_size', 'valid', 'invalid', 'plaintext', 'placeholder', 'name', 'pattern', 'n_submit', 'n_submit_timestamp', 'n_blur', 'n_blur_timestamp', 'debounce', 'loading_state']
        self._type = 'PasswordWithShow'
        self._namespace = 'dash_holoniq_components/_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['tooltip', 'id', 'style', 'className', 'key', 'value', 'disabled', 'autoComplete', 'autoFocus', 'inputMode', 'list', 'max', 'maxLength', 'min', 'minLength', 'step', 'size', 'bs_size', 'valid', 'invalid', 'plaintext', 'placeholder', 'name', 'pattern', 'n_submit', 'n_submit_timestamp', 'n_blur', 'n_blur_timestamp', 'debounce', 'loading_state']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(PasswordWithShow, self).__init__(**args)



import os
import sys

from . import _components
from ._components import *  # noqa
from ._version import __version__  # noqa

_current_path = os.path.dirname(os.path.abspath(__file__))

METADATA_PATH = os.path.join(_current_path, "_components", "metadata.json")

_js_dist = [
    {
        "relative_package_path": (
            "_components/dash_holoniq_components.min.js"
        ),
        "namespace": "dash_holoniq_components",
    }
]

_css_dist = []


for _component_name in _components.__all__:
    _component = getattr(_components, _component_name)
    _component._js_dist = _js_dist
    _component._css_dist = _css_dist





import os

from setuptools import find_packages, setup

HERE = os.path.dirname(os.path.abspath(__file__))


def _get_version():
    """ Get version by parsing _version programmatically """
    version_ns = {}
    with open(
        os.path.join(HERE, "dash_holoniq_components", "_version.py")
    ) as f:
        exec(f.read(), {}, version_ns)
    version = version_ns["__version__"]
    return version

def _get_long_description():
    with open(os.path.join(HERE, "landing-page.md")) as f:
        return f.read()

setup(
    name="dash-holoniq-components",
    version=_get_version(),
    description="Custom components for use in Plotly Dash",
    long_description=_get_long_description(),
    long_description_content_type="text/markdown",
    url='https://github.com/stevej2608/dash-holoniq-components',
    author='Steve Jones',
    author_email='jonesst2608@gmail.com',
    license="Apache Software License",
    packages=find_packages(),
    install_requires=["dash>=0.41.0", "dash-bootstrap-components>=0.7.1"],
    include_package_data=True,
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Environment :: Web Environment",
        "Framework :: Flask",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Financial and Insurance Industry",
        "Intended Audience :: Healthcare Industry",
        "Intended Audience :: Manufacturing",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Database :: Front-Ends",
        "Topic :: Office/Business :: Financial :: Spreadsheet",
        "Topic :: Scientific/Engineering :: Visualization",
        "Topic :: Software Development :: Libraries :: Application Frameworks",
        "Topic :: Software Development :: Widget Sets",
    ]
)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Form(Component):
    """A Form component.
The `Form` components normal submit action is inhibited. Instead the forms 
data, as it would be reported by the default form action, is collected and is
available via the form_data attribute.

Keyword arguments:
- children (a list of or a singular dash component, string or number; optional): The children of this component
- id (string; optional): The ID of this component, used to identify dash components
in callbacks. The ID needs to be unique across all of the
components in an app.
- style (dict; optional): Defines CSS styles which will override styles previously set.
- className (string; optional): Often used with CSS to style elements with common properties.
- key (string; optional): A unique identifier for the component, used to improve
performance by React.js while rendering components
See https://reactjs.org/docs/lists-and-keys.html for more info
- inline (boolean; optional): Use inline=True to apply the `form-inline` class, allowing you to display
a series of labels, form controls, and buttons on a single horizontal row.
Form controls within inline forms vary slightly from their default states.
- preventDefault (boolean; optional): Use preventDefault=True to block the forms default action
- form_data (dict; optional): The forms data as it would be reported by the default form action
- loading_state (dict; optional): Object that holds the loading state object coming from dash-renderer. loading_state has the following type: dict containing keys 'is_loading', 'prop_name', 'component_name'.
Those keys have the following types:
  - is_loading (boolean; optional): Determines if the component is loading or not
  - prop_name (string; optional): Holds which property is loading
  - component_name (string; optional): Holds the name of the component that is loading"""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, inline=Component.UNDEFINED, preventDefault=Component.UNDEFINED, form_data=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'style', 'className', 'key', 'inline', 'preventDefault', 'form_data', 'loading_state']
        self._type = 'Form'
        self._namespace = 'dash_holoniq_components/_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'style', 'className', 'key', 'inline', 'preventDefault', 'form_data', 'loading_state']
        self.available_wildcard_properties =            []

        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Form, self).__init__(children=children, **args)
